==> limesuite-20.01.0-2-aarch64.pkg.tar.xz: usr/share/doc/limesuite/group___f_n___s_t_r_e_a_m.js <==
var group___f_n___s_t_r_e_a_m =
[
    [ "Additional streaming options", "group___s_t_r_e_a_m___c_h___f_l_a_g_s.html", "group___s_t_r_e_a_m___c_h___f_l_a_g_s" ],
    [ "lms_stream_meta_t", "structlms__stream__meta__t.html", [
      [ "flushPartialPacket", "structlms__stream__meta__t.html#a14c369920af2b7aab98d845254003136", null ],
      [ "timestamp", "structlms__stream__meta__t.html#a465bef81f6478756e5443025b1f2ddfa", null ],
      [ "waitForTimestamp", "structlms__stream__meta__t.html#acaf96b7ab272b5c752d46a26f8eb8f38", null ]
    ] ],
    [ "lms_stream_t", "structlms__stream__t.html", [
      [ "LMS_FMT_F32", "structlms__stream__t.html#adf764cbdea00d65edcd07bb9953ad2b7a5368edf0109d6d3061765766ddb512ff", null ],
      [ "LMS_FMT_I16", "structlms__stream__t.html#adf764cbdea00d65edcd07bb9953ad2b7a6314dd102d67547f52430444b62aecaa", null ],
      [ "LMS_FMT_I12", "structlms__stream__t.html#adf764cbdea00d65edcd07bb9953ad2b7ac787884d333138f79fb7ca82a51e3555", null ],
      [ "channel", "structlms__stream__t.html#a0c72dd5e18823aef187a34137983c9a6", null ],
      [ "dataFmt", "structlms__stream__t.html#aa474089eae4ea7c4d145f0e743380844", null ],
      [ "fifoSize", "structlms__stream__t.html#ae91dee986c10a4af66d70d866754c712", null ],
      [ "handle", "structlms__stream__t.html#aaa5ae1b6a83af59ef0fc6ca1000f534e", null ],
      [ "isTx", "structlms__stream__t.html#abe95fdea4e4d4f53073f93c676eaa46a", null ],
      [ "throughputVsLatency", "structlms__stream__t.html#a1d7a64c07f32bfb830b306a9a77d1f6e", null ]
    ] ],
    [ "lms_stream_status_t", "structlms__stream__status__t.html", [
      [ "active", "structlms__stream__status__t.html#a03c996f9fcf0e10baeb3e700be0c409a", null ],
      [ "droppedPackets", "structlms__stream__status__t.html#acbfb389a85cacf2bf7ac30ee9e26ce9c", null ],
      [ "fifoFilledCount", "structlms__stream__status__t.html#ae3c64c666a4042b862a41fa98dcf302b", null ],
      [ "fifoSize", "structlms__stream__status__t.html#ae91dee986c10a4af66d70d866754c712", null ],
      [ "linkRate", "structlms__stream__status__t.html#a08deeced9293825f99366b8c2cc45482", null ],
      [ "overrun", "structlms__stream__status__t.html#a38f741868cf9a2f02777e1a83bf0fa1a", null ],
      [ "sampleRate", "structlms__stream__status__t.html#a00f67abd1a9c02fd8218db5e1ef333ec", null ],
      [ "timestamp", "structlms__stream__status__t.html#a465bef81f6478756e5443025b1f2ddfa", null ],
      [ "underrun", "structlms__stream__status__t.html#a88726a9a05d1252e1d5280c5bf08bc2d", null ]
    ] ],
    [ "LMS_DestroyStream", "group___f_n___s_t_r_e_a_m.html#ga6ec705cb6d8eeccc40bcd78ee121e672", null ],
    [ "LMS_EnableTxWFM", "group___f_n___s_t_r_e_a_m.html#gac42ce47c7eb07e1cccce667ced4c19a2", null ],
    [ "LMS_GetStreamStatus", "group___f_n___s_t_r_e_a_m.html#ga3fb6de3c631d876585f137ca3c03a7d9", null ],
    [ "LMS_RecvStream", "group___f_n___s_t_r_e_a_m.html#gaaa4aebcb24e6d95ca2381747f6e344cf", null ],
    [ "LMS_SendStream", "group___f_n___s_t_r_e_a_m.html#gac81a4c776facecae17e6e5567585ad46", null ],
    [ "LMS_SetupStream", "group___f_n___s_t_r_e_a_m.html#ga77a9a5cd43aea28499a07f93951640b2", null ],
    [ "LMS_StartStream", "group___f_n___s_t_r_e_a_m.html#gacb3467ac8414b8e81217fb7c4e8adf87", null ],
    [ "LMS_StopStream", "group___f_n___s_t_r_e_a_m.html#ga68d4a388aa6674666739fa0220237c4e", null ],
    [ "LMS_UploadWFM", "group___f_n___s_t_r_e_a_m.html#ga39a8acd245a2fe634b228c8fdfc3dbb0", null ]
];

==> limesuite-23.11.0-8-aarch64.pkg.tar.xz: usr/share/doc/limesuite/group___f_n___s_t_r_e_a_m.js <==
var group___f_n___s_t_r_e_a_m =
[
    [ "Additional streaming options", "group___s_t_r_e_a_m___c_h___f_l_a_g_s.html", "group___s_t_r_e_a_m___c_h___f_l_a_g_s" ],
    [ "lms_stream_meta_t", "structlms__stream__meta__t.html", [
      [ "flushPartialPacket", "structlms__stream__meta__t.html#a14c369920af2b7aab98d845254003136", null ],
      [ "timestamp", "structlms__stream__meta__t.html#a465bef81f6478756e5443025b1f2ddfa", null ],
      [ "waitForTimestamp", "structlms__stream__meta__t.html#acaf96b7ab272b5c752d46a26f8eb8f38", null ]
    ] ],
    [ "lms_stream_t", "structlms__stream__t.html", [
      [ "channel", "structlms__stream__t.html#a0c72dd5e18823aef187a34137983c9a6", null ],
      [ "dataFmt", "structlms__stream__t.html#a01e33ae66b1afb65a4abd6e502f39a09", null ],
      [ "fifoSize", "structlms__stream__t.html#ae91dee986c10a4af66d70d866754c712", null ],
      [ "handle", "structlms__stream__t.html#aaa5ae1b6a83af59ef0fc6ca1000f534e", null ],
      [ "isTx", "structlms__stream__t.html#abe95fdea4e4d4f53073f93c676eaa46a", null ],
      [ "linkFmt", "structlms__stream__t.html#a54587095acd8cc015b8d1be3c9c2fa2f", null ],
      [ "throughputVsLatency", "structlms__stream__t.html#a1d7a64c07f32bfb830b306a9a77d1f6e", null ]
    ] ],
    [ "lms_stream_status_t", "structlms__stream__status__t.html", [
      [ "active", "structlms__stream__status__t.html#a03c996f9fcf0e10baeb3e700be0c409a", null ],
      [ "droppedPackets", "structlms__stream__status__t.html#acbfb389a85cacf2bf7ac30ee9e26ce9c", null ],
      [ "fifoFilledCount", "structlms__stream__status__t.html#ae3c64c666a4042b862a41fa98dcf302b", null ],
      [ "fifoSize", "structlms__stream__status__t.html#ae91dee986c10a4af66d70d866754c712", null ],
      [ "linkRate", "structlms__stream__status__t.html#a08deeced9293825f99366b8c2cc45482", null ],
      [ "overrun", "structlms__stream__status__t.html#a38f741868cf9a2f02777e1a83bf0fa1a", null ],
      [ "sampleRate", "structlms__stream__status__t.html#a00f67abd1a9c02fd8218db5e1ef333ec", null ],
      [ "timestamp", "structlms__stream__status__t.html#a465bef81f6478756e5443025b1f2ddfa", null ],
      [ "underrun", "structlms__stream__status__t.html#a88726a9a05d1252e1d5280c5bf08bc2d", null ]
    ] ],
    [ "LMS_DestroyStream", "group___f_n___s_t_r_e_a_m.html#ga6ec705cb6d8eeccc40bcd78ee121e672", null ],
    [ "LMS_EnableTxWFM", "group___f_n___s_t_r_e_a_m.html#gac42ce47c7eb07e1cccce667ced4c19a2", null ],
    [ "LMS_GetStreamStatus", "group___f_n___s_t_r_e_a_m.html#ga3fb6de3c631d876585f137ca3c03a7d9", null ],
    [ "LMS_RecvStream", "group___f_n___s_t_r_e_a_m.html#gaaa4aebcb24e6d95ca2381747f6e344cf", null ],
    [ "LMS_SendStream", "group___f_n___s_t_r_e_a_m.html#gac81a4c776facecae17e6e5567585ad46", null ],
    [ "LMS_SetupStream", "group___f_n___s_t_r_e_a_m.html#ga77a9a5cd43aea28499a07f93951640b2", null ],
    [ "LMS_StartStream", "group___f_n___s_t_r_e_a_m.html#gacb3467ac8414b8e81217fb7c4e8adf87", null ],
    [ "LMS_StopStream", "group___f_n___s_t_r_e_a_m.html#ga68d4a388aa6674666739fa0220237c4e", null ],
    [ "LMS_UploadWFM", "group___f_n___s_t_r_e_a_m.html#ga39a8acd245a2fe634b228c8fdfc3dbb0", null ]
];
